@@ -41,18 +41,19 @@ pub struct GitConfig {
 
 /// Parser for grouping commits.
 #[derive(Debug, Clone, serde_derive::Serialize, serde_derive::Deserialize)]
-#[serde(rename_all = "camelCase")]
 pub struct CommitParser {
 	/// Regex for matching the commit message.
 	#[serde(with = "serde_regex", default)]
-	pub message: Option<Regex>,
+	pub message:       Option<Regex>,
 	/// Regex for matching the commit body.
 	#[serde(with = "serde_regex", default)]
-	pub body:    Option<Regex>,
+	pub body:          Option<Regex>,
 	/// Group of the commit.
-	pub group:   Option<String>,
+	pub group:         Option<String>,
+	/// Scope of the commit.
+	pub default_scope: Option<String>,
 	/// Whether to skip this commit group.
-	pub skip:    Option<bool>,
+	pub skip:          Option<bool>,
 }
 
 impl Config {
